==> ocre_v0_033.tgz: ocre-0.033/ocre/src/lectura.c <==

#include <libintl.h>
#include <locale.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include "artefactos.h"
#include "convcar.h"
#include "doblesHor.h"
#include "glifos.h"
#include "imag.h"
#include "imagAcum.h"
#include "imagAcum2.h"
#include "imagx.h"
#include "libro.h"
#include "lineaText.h"
#include "opcns.h"
#include "parcela.h"
#include "pauta.h"
#include "reconoce.h"
#include "repasa.h"
#include "segmenta.h"
#include "tipos.h"

void segmReconoceyRepasaColumnaP (tglifo * nglifoColumnaP, tvent vent, int * n)
{
  tglifo glifoColumnaP;
  int nc;
  int ng, ng2;
  segmentaColumnaP (vent);
  glifoColumnaP = glifoCompClmpNuevo ();
  casaGlifoVent (glifoColumnaP, vent);
  reconoceColumnaP (glifoColumnaP);
  repasaPautas (glifoColumnaP);
  quitaArtefactos (glifoColumnaP);
  enlazaPalabrasPartidas (glifoColumnaP);
  repasaColumnaP (glifoColumnaP);
  // enlazaPalabrasPartidas (glifoColumnaP);  // nuevas lecturas?
/**/
  repasaDobleshColumnaP (glifoColumnaP);
  // repasaPautas (glifoColumnaP);
  calculaAlineamientos (glifoColumnaP); 
/**/
/* comienzo_local */
  if (p_valori == 32) {
    // escribePalabrasdeGlifosenLista (glifoColumnaP->listaGlifos);
    separaTipos (glifoColumnaP);
    exit (0);
    }
/* fin_local */
  ng  = *n ;
  ng2 = *n ;
  numeraGlifosenLista (glifoColumnaP, &ng2);
/* comienzo_local */
  if (p_valori == 22) {
    escribePalabrasdeGlifosenLista (glifoColumnaP->listaGlifos);
    }
  else if (p_valori == 29) {
    escribePalabrasLogdeGlifosenLista (glifoColumnaP->listaGlifos);
    }
  else
/* fin_local */
    escribeLetrasdeGlifosenLista (glifoColumnaP->listaGlifos, n);
/* comienzo_local */
  if (p_valori == 5){
    escribeVentanasdeGlifosenLista (glifoColumnaP, &ng, "arm1");
    if (ng != ng2)
      printf (" error en segmReconoceyRepasaColumnaP, ng: %4d ng2: %4d\n",
               ng, ng2) ;
    }
  if (S_opcion) {
    nc = nincognitasEnGlifo (glifoColumnaP);
    printf ("glifos no reconocidos: %5d\n", nc);
    marcaGlifosNoReconocidos (glifoColumnaP) ;
    presentaVentanayPara (vent, "sal26.pgm", 1);
    }
/* fin_local */
  *nglifoColumnaP = glifoColumnaP;
}

void segmReconoceyRepasaG (tglifo * nglifoG, tvent vent, int * n)
{
  tvent ventPag0, ventPag1;
  tglifo glifoPliego;
  tglifo glifoPag0, glifoPag1;
  if (b_opcion) {
    /* if (bvalor[0] == 'c') .... */
    segmentaLibroPaginas (vent, &ventPag0, &ventPag1);
    glifoPliego = glifoCompPliegoNuevo ();
    casaGlifoVent (glifoPliego, vent);
    /*
    */
    segmReconoceyRepasaColumnaP (&glifoPag0, ventPag0, n);
    adoptaGlifo (glifoPliego, glifoPag0);
    segmReconoceyRepasaColumnaP (&glifoPag1, ventPag1, n);
    adoptaGlifo (glifoPliego, glifoPag1);
    *nglifoG = glifoPliego;
    }
  else if (A_opcion) {
    parcela (vent);
    printf ("paso por segmReconoceyRepasaG con A_opcion\n");
    }
  else
    segmReconoceyRepasaColumnaP (nglifoG, vent, n);
  if (C_opcion) {
    timagAcum imagAcum;
    timagf imaga;
    char caracUnic[128], caracUstr[128];
    char nomsal[128];
    if ( esUstr(C_valor) ){
      utf8DeUstr (caracUnic, C_valor);
      strcpy (caracUstr, C_valor);
      }
    else {
      strcpy (caracUnic, C_valor);
      ustrDeUtf8 (caracUstr, C_valor);
      }
    imagAcum = imagenAcumDecharsEnglifo (8, caracUnic, *nglifoG);
    printf(" %s: %4d\n", caracUstr, imagAcum->n);
    if (imagAcum->n > 0) {
      imagenDeImagenAcum (&imaga, imagAcum);
      sprintf (nomsal, "carRef%s.pgm", caracUstr);
      presentaVentanayPara (imaga->ven0, nomsal, 1);
      }
    }
}

==> ocre_v0_037.tgz: ocre-0.037/ocre/src/lectura.c <==

#include <libintl.h>
#include <locale.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include "artefactos.h"
#include "atributos.h"
#include "convcar.h"
#include "doblesHor.h"
#include "glifos.h"
#include "grises.h"
#include "histos.h"
#include "imag.h"
#include "imagAcum.h"
#include "imagAcum2.h"
#include "imagx.h"
#include "libro.h"
#include "lineaText.h"
#include "opcns.h"
#include "parcela.h"
#include "pauta.h"
#include "reconoce.h"
#include "repasa.h"
#include "segmenta0.h"
#include "segmenta.h"
#include "tipos.h"

void segmReconoceyRepasaColumnaP (tglifo * nglifoColumnaP, tvent vent, int * n)
{
  tglifo glifoColumnaP;
  int nc;
  int ng, ng2;
  tvent ventSc, ventCap;
  Boolean hayCap;
  tglifo glifoCap;
//  segmentaSiCapitular (&hayCap, vent);
  segmentaSiCapitular (&hayCap, &ventSc, &ventCap, vent);
//  ventSc = vent;
  segmentaColumnaP (ventSc);
  glifoColumnaP = glifoCompClmpNuevo ();
  casaGlifoVent (glifoColumnaP, ventSc);
  reconoceColumnaP (glifoColumnaP);
  if (hayCap) {
    glifoCap = glifoLetNuevo ("0?");
    casaGlifoVent (glifoCap, ventCap);
    anyadeAtributoAlista (ventCap->atributs, "capitular", (tpgen)TRUE);
    reconoceChar (glifoCap, 3);   // 3 o menor, opcns.c
    ponCapitularenGlifoCP (glifoColumnaP, ventCap, vent);
    }
  // correcciones
  repasaPautas (glifoColumnaP);
  quitaArtefactos (glifoColumnaP);
  corrigeGuionesFindeLinea (glifoColumnaP);
  enlazaPalabrasPartidas (glifoColumnaP);
  //
  repasaColumnaP (glifoColumnaP);
  // enlazaPalabrasPartidas (glifoColumnaP);  // nuevas lecturas?
/**/
  repasaDobleshColumnaP (glifoColumnaP);
  // repasaPautas (glifoColumnaP);
  calculaAlineamientos (glifoColumnaP); 
/**/
/* comienzo_local */
  if (p_valori == 32) {
    // escribePalabrasdeGlifosenLista (glifoColumnaP->listaGlifos);
    separaTipos (glifoColumnaP);
    exit (0);
    }
/* fin_local */
  ng  = *n ;
  ng2 = *n ;
  numeraGlifosenLista (glifoColumnaP, &ng2);
/* comienzo_local */
  if (p_valori == 22) {
    escribePalabrasdeGlifosenLista (glifoColumnaP->listaGlifos);
    }
  else if (p_valori == 29) {
    escribePalabrasLogdeGlifosenLista (glifoColumnaP->listaGlifos);
    }
  else
/* fin_local */
    escribeLetrasdeGlifosenLista (glifoColumnaP->listaGlifos, n);
/* comienzo_local */
  if (p_valori == 5){
    escribeVentanasdeGlifosenLista (glifoColumnaP, &ng, "arm1");
    if (ng != ng2)
      printf (" error en segmReconoceyRepasaColumnaP, ng: %4d ng2: %4d\n",
               ng, ng2) ;
    }
  if (S_opcion) {
    nc = nincognitasEnGlifo (glifoColumnaP);
    printf ("glifos no reconocidos: %5d\n", nc);
    marcaGlifosNoReconocidos (glifoColumnaP) ;
    presentaVentanayPara (ventSc, "sal26.pgm", 1);
    }
/* fin_local */
  *nglifoColumnaP = glifoColumnaP;
}

void segmReconoceyRepasaG (tglifo * nglifoG, tvent vent, int * n)
{
  tvent ventPag0, ventPag1;
  tglifo glifoPliego;
  tglifo glifoPag0, glifoPag1;
  if (b_opcion) {
    /* if (bvalor[0] == 'c') .... */
    segmentaLibroPaginas (vent, &ventPag0, &ventPag1);
    glifoPliego = glifoCompPliegoNuevo ();
    casaGlifoVent (glifoPliego, vent);
    /*
    */
    segmReconoceyRepasaColumnaP (&glifoPag0, ventPag0, n);
    adoptaGlifo (glifoPliego, glifoPag0);
    segmReconoceyRepasaColumnaP (&glifoPag1, ventPag1, n);
    adoptaGlifo (glifoPliego, glifoPag1);
    *nglifoG = glifoPliego;
    }
  else if (A_opcion) {
    parcela (vent);
    printf ("paso por segmReconoceyRepasaG con A_opcion\n");
    }
  else
    segmReconoceyRepasaColumnaP (nglifoG, vent, n);
  if (C_opcion) {
    timagAcum imagAcum;
    timagf imaga;
    char caracUnic[128], caracUstr[128];
    char nomsal[128];
    if ( esUstr(C_valor) ){
      utf8DeUstr (caracUnic, C_valor);
      strcpy (caracUstr, C_valor);
      }
    else {
      strcpy (caracUnic, C_valor);
      ustrDeUtf8 (caracUstr, C_valor);
      }
    imagAcum = imagenAcumDecharsEnglifo (8, caracUnic, *nglifoG);
    printf(" %s: %4d\n", caracUstr, imagAcum->n);
    if (imagAcum->n > 0) {
      imagenDeImagenAcum (&imaga, imagAcum);
      sprintf (nomsal, "carRef%s.pgm", caracUstr);
      presentaVentanayPara (imaga->ven0, nomsal, 1);
      }
    }
}
